@@ -1,7 +1,7 @@
 from enum import Enum, auto
 from typing import Any, Dict, List, Union
 
-from flet_core import alignment
+from flet_core import Column, Container, Row, Stack, alignment
 
 Element = Dict[str, Any]
 Options = Union[List[str], str]
@@ -53,3 +53,15 @@ class Location(Enum):
     BottomLeft = alignment.bottom_left
     BottomCenter = alignment.bottom_center
     BottomRight = alignment.bottom_right
+
+
+SupportedFletLayout = Union[Row, Column, Container, Stack]
+
+
+class PageNotOpenError(RuntimeError):
+    """Raised when a method is called that requires the dialog to be open but dialog
+    was not yet open"""
+
+
+class LayoutError(ValueError):
+    """Raised when an invalid layout is made. Debug, and do not catch these."""
